# PreviewThruDatePolicy

The options on how the preview through date is calculated.  - If you set this field to `nextBillingPeriods`, you must specify the number of billing periods to preview in the `nextBillingPeriods` field. - If you set this field to `endOfTerm`, the preview through date is the end date of the subscription term. - If you set this field to `specificDate`, you must specify a specific date in the `specificDate` field. The date must be in the format `yyyy-mm-dd`. 

## Enum

* `NEXTBILLINGPERIODS` (value: `'nextBillingPeriods'`)

* `ENDOFTERM` (value: `'endOfTerm'`)

* `SPECIFICDATE` (value: `'specificDate'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


